@@ -19,7 +19,7 @@ type currentPitr struct {
 	cancel context.CancelFunc
 }
 
-func (a *Agent) setPitr(p *currentPitr) (changed bool) {
+func (a *Agent) setPitr(p *currentPitr) bool {
 	a.mx.Lock()
 	defer a.mx.Unlock()
 	if a.pitrjob != nil {
@@ -84,7 +84,7 @@ func (a *Agent) stopPitrOnOplogOnlyChange(currOO bool) {
 	}
 }
 
-func (a *Agent) pitr() (err error) {
+func (a *Agent) pitr() error {
 	// pausing for physical restore
 	if !a.HbIsRun() {
 		return nil
@@ -213,12 +213,11 @@ func (a *Agent) pitr() (err error) {
 
 		streamErr := ibcp.Stream(ctx, w, cfg.PITR.Compression, cfg.PITR.CompressionLevel, cfg.Backup.Timeouts)
 		if streamErr != nil {
-			switch streamErr.(type) {
-			case pitr.ErrOpMoved:
-				l.Info("streaming oplog: %v", streamErr)
-			default:
-				l.Error("streaming oplog: %v", streamErr)
+			out := l.Error
+			if errors.Is(streamErr, pitr.OpMovedError{}) {
+				out = l.Info
 			}
+			out("streaming oplog: %v", streamErr)
 		}
 
 		if err := lock.Release(); err != nil {
@@ -238,7 +237,7 @@ func (a *Agent) pitr() (err error) {
 	return nil
 }
 
-func (a *Agent) pitrLockCheck() (moveOn bool, err error) {
+func (a *Agent) pitrLockCheck() (bool, error) {
 	ts, err := a.pbm.ClusterTime()
 	if err != nil {
 		return false, errors.Wrap(err, "read cluster time")
@@ -246,8 +245,8 @@ func (a *Agent) pitrLockCheck() (moveOn bool, err error) {
 
 	tl, err := a.pbm.GetLockData(&pbm.LockHeader{Replset: a.node.RS()})
 	if err != nil {
-		// mongo.ErrNoDocuments means no lock and we're good to move on
-		if err == mongo.ErrNoDocuments {
+		if errors.Is(err, mongo.ErrNoDocuments) {
+			// no lock. good to move on
 			return true, nil
 		}
 
@@ -303,8 +302,8 @@ func (a *Agent) Restore(r *pbm.RestoreCmd, opid pbm.OPID, ep pbm.Epoch) {
 			if lock == nil {
 				return
 			}
-			err := lock.Release()
-			if err != nil {
+
+			if err := lock.Release(); err != nil {
 				l.Error("release lock: %v", err)
 			}
 		}()
@@ -323,15 +322,17 @@ func (a *Agent) Restore(r *pbm.RestoreCmd, opid pbm.OPID, ep pbm.Epoch) {
 		bcpType = pbm.ExternalBackup
 	} else {
 		l.Info("backup: %s", r.BackupName)
-		if !r.OplogTS.IsZero() {
-			bcp, err = restore.GetBaseBackup(a.pbm, r.BackupName, r.OplogTS, stg)
-		} else {
-			bcp, err = restore.SnapshotMeta(a.pbm, r.BackupName, stg)
-		}
+		bcp, err = restore.SnapshotMeta(a.pbm, r.BackupName, stg)
 		if err != nil {
 			l.Error("define base backup: %v", err)
 			return
 		}
+
+		if !r.OplogTS.IsZero() && bcp.LastWriteTS.Compare(r.OplogTS) >= 0 {
+			l.Error("snapshot's last write is later than the target time. " +
+				"Try to set an earlier snapshot. Or leave the snapshot empty so PBM will choose one.")
+			return
+		}
 		bcpType = bcp.Type
 	}
 
