@@ -5,6 +5,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	stdlog "log"
 	"os"
 	"strings"
 	"time"
@@ -55,135 +56,262 @@ type cliResult interface {
 
 func Main() {
 	var (
-		pbmCmd       = kingpin.New("pbm", "Percona Backup for MongoDB")
-		mURL         = pbmCmd.Flag("mongodb-uri", "MongoDB connection string (Default = PBM_MONGODB_URI environment variable)").Envar("PBM_MONGODB_URI").String()
-		pbmOutFormat = pbmCmd.Flag("out", "Output format <text>/<json>").Short('o').Default(string(outText)).Enum(string(outJSON), string(outJSONpretty), string(outText))
+		pbmCmd = kingpin.New("pbm", "Percona Backup for MongoDB")
+		mURL   = pbmCmd.Flag("mongodb-uri",
+			"MongoDB connection string (Default = PBM_MONGODB_URI environment variable)").
+			Envar("PBM_MONGODB_URI").
+			String()
+		pbmOutFormat = pbmCmd.Flag("out", "Output format <text>/<json>").
+				Short('o').
+				Default(string(outText)).
+				Enum(string(outJSON), string(outJSONpretty), string(outText))
 	)
 	pbmCmd.HelpFlag.Short('h')
 
 	versionCmd := pbmCmd.Command("version", "PBM version info")
-	versionShort := versionCmd.Flag("short", "Show only version info").Short('s').Default("false").Bool()
-	versionCommit := versionCmd.Flag("commit", "Show only git commit info").Short('c').Default("false").Bool()
+	versionShort := versionCmd.Flag("short", "Show only version info").
+		Short('s').
+		Default("false").
+		Bool()
+	versionCommit := versionCmd.Flag("commit", "Show only git commit info").
+		Short('c').
+		Default("false").
+		Bool()
 
 	configCmd := pbmCmd.Command("config", "Set, change or list the config")
 	cfg := configOpts{set: make(map[string]string)}
-	configCmd.Flag("force-resync", "Resync backup list with the current store").BoolVar(&cfg.rsync)
-	configCmd.Flag("list", "List current settings").BoolVar(&cfg.list)
-	configCmd.Flag("file", "Upload config from YAML file").StringVar(&cfg.file)
-	configCmd.Flag("set", "Set the option value <key.name=value>").StringMapVar(&cfg.set)
-	configCmd.Arg("key", "Show the value of a specified key").StringVar(&cfg.key)
+	configCmd.Flag("force-resync", "Resync backup list with the current store").
+		BoolVar(&cfg.rsync)
+	configCmd.Flag("list", "List current settings").
+		BoolVar(&cfg.list)
+	configCmd.Flag("file", "Upload config from YAML file").
+		StringVar(&cfg.file)
+	configCmd.Flag("set", "Set the option value <key.name=value>").
+		StringMapVar(&cfg.set)
+	configCmd.Arg("key", "Show the value of a specified key").
+		StringVar(&cfg.key)
 
 	backupCmd := pbmCmd.Command("backup", "Make backup")
 	backup := backupOpts{}
 	backupCmd.Flag("compression", "Compression type <none>/<gzip>/<snappy>/<lz4>/<s2>/<pgzip>/<zstd>").
 		EnumVar(&backup.compression,
-			string(compress.CompressionTypeNone), string(compress.CompressionTypeGZIP),
-			string(compress.CompressionTypeSNAPPY), string(compress.CompressionTypeLZ4),
-			string(compress.CompressionTypeS2), string(compress.CompressionTypePGZIP),
-			string(compress.CompressionTypeZstandard),
-		)
+			string(compress.CompressionTypeNone),
+			string(compress.CompressionTypeGZIP),
+			string(compress.CompressionTypeSNAPPY),
+			string(compress.CompressionTypeLZ4),
+			string(compress.CompressionTypeS2),
+			string(compress.CompressionTypePGZIP),
+			string(compress.CompressionTypeZstandard))
 	backupCmd.Flag("type",
 		fmt.Sprintf("backup type: <%s>/<%s>/<%s>/<%s>",
-			pbm.PhysicalBackup, pbm.LogicalBackup, pbm.IncrementalBackup, pbm.ExternalBackup)).
-		Default(string(pbm.LogicalBackup)).Short('t').
+			pbm.PhysicalBackup,
+			pbm.LogicalBackup,
+			pbm.IncrementalBackup,
+			pbm.ExternalBackup)).
+		Default(string(pbm.LogicalBackup)).
+		Short('t').
 		EnumVar(&backup.typ,
 			string(pbm.PhysicalBackup),
 			string(pbm.LogicalBackup),
 			string(pbm.IncrementalBackup),
-			string(pbm.ExternalBackup),
-		)
-	backupCmd.Flag("base", "Is this a base for incremental backups").BoolVar(&backup.base)
+			string(pbm.ExternalBackup))
+	backupCmd.Flag("base", "Is this a base for incremental backups").
+		BoolVar(&backup.base)
 	backupCmd.Flag("compression-level", "Compression level (specific to the compression type)").
 		IntsVar(&backup.compressionLevel)
-	backupCmd.Flag("ns", `Namespaces to backup (e.g. "db.*", "db.collection"). If not set, backup all ("*.*")`).StringVar(&backup.ns)
-	backupCmd.Flag("wait", "Wait for the backup to finish").Short('w').BoolVar(&backup.wait)
-	backupCmd.Flag("list-files", "Wait for the backup to finish").Short('l').BoolVar(&backup.externList)
+	backupCmd.Flag("ns", `Namespaces to backup (e.g. "db.*", "db.collection"). If not set, backup all ("*.*")`).
+		StringVar(&backup.ns)
+	backupCmd.Flag("wait", "Wait for the backup to finish").
+		Short('w').
+		BoolVar(&backup.wait)
+	backupCmd.Flag("list-files", "Wait for the backup to finish").
+		Short('l').
+		BoolVar(&backup.externList)
 
 	cancelBcpCmd := pbmCmd.Command("cancel-backup", "Cancel backup")
 
 	descBcpCmd := pbmCmd.Command("describe-backup", "Describe backup")
 	descBcp := descBcp{}
-	descBcpCmd.Arg("backup_name", "Backup name").StringVar(&descBcp.name)
+	descBcpCmd.Flag("with-collections", "Show collections in backup").
+		BoolVar(&descBcp.coll)
+	descBcpCmd.Arg("backup_name", "Backup name").
+		StringVar(&descBcp.name)
 
 	finishBackupName := ""
 	backupFinishCmd := pbmCmd.Command("backup-finish", "Finish external backup")
-	backupFinishCmd.Arg("backup_name", "Backup name").StringVar(&finishBackupName)
+	backupFinishCmd.Arg("backup_name", "Backup name").
+		StringVar(&finishBackupName)
 
 	finishRestore := descrRestoreOpts{}
 	restoreFinishCmd := pbmCmd.Command("restore-finish", "Finish external backup")
-	restoreFinishCmd.Arg("restore_name", "Restore name").StringVar(&finishRestore.restore)
-	restoreFinishCmd.Flag("config", "Path to PBM config").Short('c').Required().StringVar(&finishRestore.cfg)
+	restoreFinishCmd.Arg("restore_name", "Restore name").
+		StringVar(&finishRestore.restore)
+	restoreFinishCmd.Flag("config", "Path to PBM config").
+		Short('c').
+		Required().
+		StringVar(&finishRestore.cfg)
 
 	restoreCmd := pbmCmd.Command("restore", "Restore backup")
 	restore := restoreOpts{}
-	restoreCmd.Arg("backup_name", "Backup name to restore").StringVar(&restore.bcp)
-	restoreCmd.Flag("time", fmt.Sprintf("Restore to the point-in-time. Set in format %s", datetimeFormat)).StringVar(&restore.pitr)
-	restoreCmd.Flag("base-snapshot", "Override setting: Name of older snapshot that PITR will be based on during restore.").StringVar(&restore.pitrBase)
-	restoreCmd.Flag("ns", `Namespaces to restore (e.g. "db1.*,db2.collection2"). If not set, restore all ("*.*")`).StringVar(&restore.ns)
-	restoreCmd.Flag("wait", "Wait for the restore to finish.").Short('w').BoolVar(&restore.wait)
-	restoreCmd.Flag("external", "External restore.").Short('x').BoolVar(&restore.extern)
-	restoreCmd.Flag("config", "Mongod config for the source data. External backups only!").Short('c').StringVar(&restore.conf)
-	restoreCmd.Flag("ts", "MongoDB cluster time to restore to. In <T,I> format (e.g. 1682093090,9). External backups only!").StringVar(&restore.ts)
-	restoreCmd.Flag(RSMappingFlag, RSMappingDoc).Envar(RSMappingEnvVar).StringVar(&restore.rsMap)
+	restoreCmd.Arg("backup_name", "Backup name to restore").
+		StringVar(&restore.bcp)
+	restoreCmd.Flag("time", fmt.Sprintf("Restore to the point-in-time. Set in format %s", datetimeFormat)).
+		StringVar(&restore.pitr)
+	restoreCmd.Flag("base-snapshot",
+		"Override setting: Name of older snapshot that PITR will be based on during restore.").
+		StringVar(&restore.pitrBase)
+	restoreCmd.Flag("ns", `Namespaces to restore (e.g. "db1.*,db2.collection2"). If not set, restore all ("*.*")`).
+		StringVar(&restore.ns)
+	restoreCmd.Flag("wait", "Wait for the restore to finish.").
+		Short('w').
+		BoolVar(&restore.wait)
+	restoreCmd.Flag("external", "External restore.").
+		Short('x').
+		BoolVar(&restore.extern)
+	restoreCmd.Flag("config", "Mongod config for the source data. External backups only!").
+		Short('c').
+		StringVar(&restore.conf)
+	restoreCmd.Flag("ts",
+		"MongoDB cluster time to restore to. In <T,I> format (e.g. 1682093090,9). External backups only!").
+		StringVar(&restore.ts)
+	restoreCmd.Flag(RSMappingFlag, RSMappingDoc).
+		Envar(RSMappingEnvVar).
+		StringVar(&restore.rsMap)
 
 	replayCmd := pbmCmd.Command("oplog-replay", "Replay oplog")
 	replayOpts := replayOptions{}
-	replayCmd.Flag("start", fmt.Sprintf("Replay oplog from the time. Set in format %s", datetimeFormat)).Required().StringVar(&replayOpts.start)
-	replayCmd.Flag("end", "Replay oplog to the time. Set in format %s").Required().StringVar(&replayOpts.end)
-	replayCmd.Flag("wait", "Wait for the restore to finish.").Short('w').BoolVar(&replayOpts.wait)
-	replayCmd.Flag(RSMappingFlag, RSMappingDoc).Envar(RSMappingEnvVar).StringVar(&replayOpts.rsMap)
+	replayCmd.Flag("start", fmt.Sprintf("Replay oplog from the time. Set in format %s", datetimeFormat)).
+		Required().
+		StringVar(&replayOpts.start)
+	replayCmd.Flag("end", "Replay oplog to the time. Set in format %s").
+		Required().
+		StringVar(&replayOpts.end)
+	replayCmd.Flag("wait", "Wait for the restore to finish.").
+		Short('w').
+		BoolVar(&replayOpts.wait)
+	replayCmd.Flag(RSMappingFlag, RSMappingDoc).
+		Envar(RSMappingEnvVar).
+		StringVar(&replayOpts.rsMap)
 	// todo(add oplog cancel)
 
 	listCmd := pbmCmd.Command("list", "Backup list")
 	list := listOpts{}
-	listCmd.Flag("restore", "Show last N restores").Default("false").BoolVar(&list.restore)
-	listCmd.Flag("unbacked", "Show unbacked oplog ranges").Default("false").BoolVar(&list.unbacked)
-	listCmd.Flag("full", "Show extended restore info").Default("false").Short('f').Hidden().BoolVar(&list.full)
-	listCmd.Flag("size", "Show last N backups").Default("0").IntVar(&list.size)
-	listCmd.Flag(RSMappingFlag, RSMappingDoc).Envar(RSMappingEnvVar).StringVar(&list.rsMap)
+	listCmd.Flag("restore", "Show last N restores").
+		Default("false").
+		BoolVar(&list.restore)
+	listCmd.Flag("unbacked", "Show unbacked oplog ranges").
+		Default("false").
+		BoolVar(&list.unbacked)
+	listCmd.Flag("full", "Show extended restore info").
+		Default("false").
+		Short('f').
+		Hidden().
+		BoolVar(&list.full)
+	listCmd.Flag("size", "Show last N backups").
+		Default("0").
+		IntVar(&list.size)
+	listCmd.Flag(RSMappingFlag, RSMappingDoc).
+		Envar(RSMappingEnvVar).
+		StringVar(&list.rsMap)
 
 	deleteBcpCmd := pbmCmd.Command("delete-backup", "Delete a backup")
 	deleteBcp := deleteBcpOpts{}
-	deleteBcpCmd.Arg("name", "Backup name").StringVar(&deleteBcp.name)
-	deleteBcpCmd.Flag("older-than", fmt.Sprintf("Delete backups older than date/time in format %s or %s", datetimeFormat, dateFormat)).StringVar(&deleteBcp.olderThan)
-	deleteBcpCmd.Flag("yes", "Don't ask confirmation").Short('y').BoolVar(&deleteBcp.force)
-	deleteBcpCmd.Flag("force", "Force. Don't ask confirmation").Short('f').BoolVar(&deleteBcp.force)
+	deleteBcpCmd.Arg("name", "Backup name").
+		StringVar(&deleteBcp.name)
+	deleteBcpCmd.Flag("older-than",
+		fmt.Sprintf("Delete backups older than date/time in format %s or %s",
+			datetimeFormat,
+			dateFormat)).
+		StringVar(&deleteBcp.olderThan)
+	deleteBcpCmd.Flag("yes", "Don't ask confirmation").
+		Short('y').
+		BoolVar(&deleteBcp.force)
+	deleteBcpCmd.Flag("force", "Force. Don't ask confirmation").
+		Short('f').
+		BoolVar(&deleteBcp.force)
 
 	deletePitrCmd := pbmCmd.Command("delete-pitr", "Delete PITR chunks")
 	deletePitr := deletePitrOpts{}
-	deletePitrCmd.Flag("older-than", fmt.Sprintf("Delete backups older than date/time in format %s or %s", datetimeFormat, dateFormat)).StringVar(&deletePitr.olderThan)
-	deletePitrCmd.Flag("all", "Delete all chunks").Short('a').BoolVar(&deletePitr.all)
-	deletePitrCmd.Flag("yes", "Don't ask confirmation").Short('y').BoolVar(&deletePitr.force)
-	deletePitrCmd.Flag("force", "Force. Don't ask confirmation").Short('f').BoolVar(&deletePitr.force)
+	deletePitrCmd.Flag("older-than",
+		fmt.Sprintf("Delete backups older than date/time in format %s or %s",
+			datetimeFormat,
+			dateFormat)).
+		StringVar(&deletePitr.olderThan)
+	deletePitrCmd.Flag("all", "Delete all chunks").
+		Short('a').
+		BoolVar(&deletePitr.all)
+	deletePitrCmd.Flag("yes", "Don't ask confirmation").
+		Short('y').
+		BoolVar(&deletePitr.force)
+	deletePitrCmd.Flag("force", "Force. Don't ask confirmation").
+		Short('f').
+		BoolVar(&deletePitr.force)
 
 	cleanupCmd := pbmCmd.Command("cleanup", "Delete Backups and PITR chunks")
 	cleanupOpts := cleanupOptions{}
-	cleanupCmd.Flag("older-than", fmt.Sprintf("Delete older than date/time in format %s or %s", datetimeFormat, dateFormat)).StringVar(&cleanupOpts.olderThan)
-	cleanupCmd.Flag("yes", "Don't ask confirmation").Short('y').BoolVar(&cleanupOpts.yes)
-	cleanupCmd.Flag("wait", "Wait for deletion done").Short('w').BoolVar(&cleanupOpts.wait)
-	cleanupCmd.Flag("dry-run", "Report but do not delete").BoolVar(&cleanupOpts.dryRun)
+	cleanupCmd.Flag("older-than",
+		fmt.Sprintf("Delete older than date/time in format %s or %s",
+			datetimeFormat,
+			dateFormat)).
+		StringVar(&cleanupOpts.olderThan)
+	cleanupCmd.Flag("yes", "Don't ask confirmation").
+		Short('y').
+		BoolVar(&cleanupOpts.yes)
+	cleanupCmd.Flag("wait", "Wait for deletion done").
+		Short('w').
+		BoolVar(&cleanupOpts.wait)
+	cleanupCmd.Flag("dry-run", "Report but do not delete").
+		BoolVar(&cleanupOpts.dryRun)
 
 	logsCmd := pbmCmd.Command("logs", "PBM logs")
 	logs := logsOpts{}
-	logsCmd.Flag("follow", "Follow output").Short('f').Default("false").BoolVar(&logs.follow)
-	logsCmd.Flag("tail", "Show last N entries, 20 entries are shown by default, 0 for all logs").Short('t').Default("20").Int64Var(&logs.tail)
-	logsCmd.Flag("node", "Target node in format replset[/host:posrt]").Short('n').StringVar(&logs.node)
-	logsCmd.Flag("severity", "Severity level D, I, W, E or F, low to high. Choosing one includes higher levels too.").Short('s').Default("I").EnumVar(&logs.severity, "D", "I", "W", "E", "F")
-	logsCmd.Flag("event", "Event in format backup[/2020-10-06T11:45:14Z]. Events: backup, restore, cancelBackup, resync, pitr, delete").Short('e').StringVar(&logs.event)
-	logsCmd.Flag("opid", "Operation ID").Short('i').StringVar(&logs.opid)
-	logsCmd.Flag("timezone", "Timezone of log output. `Local`, `UTC` or a location name corresponding to a file in the IANA Time Zone database, such as `America/New_York`").StringVar(&logs.location)
-	logsCmd.Flag("extra", "Show extra data in text format").Hidden().Short('x').BoolVar(&logs.extr)
+	logsCmd.Flag("follow", "Follow output").
+		Short('f').
+		Default("false").
+		BoolVar(&logs.follow)
+	logsCmd.Flag("tail", "Show last N entries, 20 entries are shown by default, 0 for all logs").
+		Short('t').
+		Default("20").
+		Int64Var(&logs.tail)
+	logsCmd.Flag("node", "Target node in format replset[/host:posrt]").
+		Short('n').
+		StringVar(&logs.node)
+	logsCmd.Flag("severity", "Severity level D, I, W, E or F, low to high. Choosing one includes higher levels too.").
+		Short('s').
+		Default("I").
+		EnumVar(&logs.severity, "D", "I", "W", "E", "F")
+	logsCmd.Flag("event",
+		"Event in format backup[/2020-10-06T11:45:14Z]. Events: backup, restore, cancelBackup, resync, pitr, delete").
+		Short('e').
+		StringVar(&logs.event)
+	logsCmd.Flag("opid", "Operation ID").
+		Short('i').
+		StringVar(&logs.opid)
+	logsCmd.Flag("timezone",
+		"Timezone of log output. `Local`, `UTC` or a location name corresponding to "+
+			"a file in the IANA Time Zone database, such as `America/New_York`").
+		StringVar(&logs.location)
+	logsCmd.Flag("extra", "Show extra data in text format").
+		Hidden().
+		Short('x').
+		BoolVar(&logs.extr)
 
 	statusOpts := statusOptions{}
 	statusCmd := pbmCmd.Command("status", "Show PBM status")
-	statusCmd.Flag(RSMappingFlag, RSMappingDoc).Envar(RSMappingEnvVar).StringVar(&statusOpts.rsMap)
-	statusCmd.Flag("sections", "Sections of status to display <cluster>/<pitr>/<running>/<backups>.").Short('s').
+	statusCmd.Flag(RSMappingFlag, RSMappingDoc).
+		Envar(RSMappingEnvVar).
+		StringVar(&statusOpts.rsMap)
+	statusCmd.Flag("sections", "Sections of status to display <cluster>/<pitr>/<running>/<backups>.").
+		Short('s').
 		EnumsVar(&statusOpts.sections, "cluster", "pitr", "running", "backups")
 
 	describeRestoreCmd := pbmCmd.Command("describe-restore", "Describe restore")
 	describeRestoreOpts := descrRestoreOpts{}
-	describeRestoreCmd.Arg("name", "Restore name").StringVar(&describeRestoreOpts.restore)
-	describeRestoreCmd.Flag("config", "Path to PBM config").Short('c').StringVar(&describeRestoreOpts.cfg)
+	describeRestoreCmd.Arg("name", "Restore name").
+		StringVar(&describeRestoreOpts.restore)
+	describeRestoreCmd.Flag("config", "Path to PBM config").
+		Short('c').
+		StringVar(&describeRestoreOpts.cfg)
 
 	cmd, err := pbmCmd.DefaultEnvars().Parse(os.Args[1:])
 	if err != nil {
@@ -196,11 +324,11 @@ func Main() {
 	if cmd == versionCmd.FullCommand() {
 		switch {
 		case *versionCommit:
-			out = outCaption{"GitCommit", version.DefaultInfo.GitCommit}
+			out = outCaption{"GitCommit", version.Current().GitCommit}
 		case *versionShort:
-			out = outCaption{"Version", version.DefaultInfo.Version}
+			out = outCaption{"Version", version.Current().Version}
 		default:
-			out = version.DefaultInfo
+			out = version.Current()
 		}
 		printo(out, pbmOutF)
 		return
@@ -208,7 +336,9 @@ func Main() {
 
 	if *mURL == "" {
 		fmt.Fprintln(os.Stderr, "Error: no mongodb connection URI supplied")
-		fmt.Fprintln(os.Stderr, "       Usual practice is the set it by the PBM_MONGODB_URI environment variable. It can also be set with commandline argument --mongodb-uri.")
+		fmt.Fprintln(os.Stderr,
+			"       Usual practice is the set it by the PBM_MONGODB_URI environment variable. "+
+				"It can also be set with commandline argument --mongodb-uri.")
 		pbmCmd.Usage(os.Args[1:])
 		os.Exit(1)
 	}
@@ -225,6 +355,14 @@ func Main() {
 			exitErr(errors.Wrap(err, "connect to mongodb"), pbmOutF)
 		}
 		pbmClient.InitLogger("", "")
+
+		ver, err := pbm.GetMongoVersion(ctx, pbmClient.Conn)
+		if err != nil {
+			stdlog.Fatalf("get mongo version: %v", err)
+		}
+		if err := pbm.FeatureSupport(ver).PBMSupport(); err != nil {
+			fmt.Fprintf(os.Stderr, "WARNING: %v\n", err)
+		}
 	}
 
 	switch cmd {
@@ -300,17 +438,16 @@ func exitErr(e error, f outFormat) {
 	case outJSON, outJSONpretty:
 		var m interface{}
 		m = e
-		if _, ok := e.(json.Marshaler); !ok {
+		if _, ok := e.(json.Marshaler); !ok { //nolint:errorlint
 			m = map[string]string{"Error": e.Error()}
 		}
-		var err error
+
+		j := json.NewEncoder(os.Stdout)
 		if f == outJSONpretty {
-			err = json.NewEncoder(os.Stdout).Encode(m)
-		} else {
-			err = json.NewEncoder(os.Stdout).Encode(m)
+			j.SetIndent("", "    ")
 		}
 
-		if err != nil {
+		if err := j.Encode(m); err != nil {
 			fmt.Fprintf(os.Stderr, "Error: encoding error \"%v\": %v", m, err)
 		}
 	default:
@@ -441,7 +578,7 @@ type outMsg struct {
 	Msg string `json:"msg"`
 }
 
-func (m outMsg) String() (s string) {
+func (m outMsg) String() string {
 	return m.Msg
 }
 
@@ -450,7 +587,7 @@ type outCaption struct {
 	v interface{}
 }
 
-func (c outCaption) String() (s string) {
+func (c outCaption) String() string {
 	return fmt.Sprint(c.v)
 }
 
@@ -516,13 +653,15 @@ func findLock(cn *pbm.PBM, fn func(*pbm.LockHeader) ([]pbm.LockData, error)) (*p
 		//  would be ok. So no reason to complicate code to avoid that.
 		if lk != nil && l.OPID != lk.OPID {
 			if err != nil {
-				return nil, errors.Errorf("conflicting ops running: [%s/%s::%s-%s] [%s/%s::%s-%s]. This conflict may naturally resolve after 10 seconds",
+				return nil, errors.Errorf("conflicting ops running: [%s/%s::%s-%s] [%s/%s::%s-%s]. "+
+					"This conflict may naturally resolve after 10 seconds",
 					l.Replset, l.Node, l.Type, l.OPID,
 					lk.Replset, lk.Node, lk.Type, lk.OPID,
 				)
 			}
 		}
 
+		l := l
 		lk = &l
 	}
 
@@ -550,7 +689,7 @@ func waitOp(pbmClient *pbm.PBM, lock *pbm.LockHeader, waitFor time.Duration) err
 			lock, err := pbmClient.GetLockData(lock)
 			if err != nil {
 				// No lock, so operation has finished
-				if err == mongo.ErrNoDocuments {
+				if errors.Is(err, mongo.ErrNoDocuments) {
 					return nil
 				}
 				return errors.Wrap(err, "get lock data")
@@ -566,11 +705,6 @@ func waitOp(pbmClient *pbm.PBM, lock *pbm.LockHeader, waitFor time.Duration) err
 	}
 }
 
-func isTTY() bool {
-	fi, err := os.Stdin.Stat()
-	return (fi.Mode()&os.ModeCharDevice) != 0 && err == nil
-}
-
 func lastLogErr(cn *pbm.PBM, op pbm.Command, after int64) (string, error) {
 	l, err := cn.LogGet(
 		&log.LogRequest{
@@ -593,15 +727,29 @@ func lastLogErr(cn *pbm.PBM, op pbm.Command, after int64) (string, error) {
 	return l.Data[0].Msg, nil
 }
 
-type concurentOpErr struct {
+type concurentOpError struct {
 	op *pbm.LockHeader
 }
 
-func (e concurentOpErr) Error() string {
+func (e concurentOpError) Error() string {
 	return fmt.Sprintf("another operation in progress, %s/%s [%s/%s]", e.op.Type, e.op.OPID, e.op.Replset, e.op.Node)
 }
 
-func (e concurentOpErr) MarshalJSON() ([]byte, error) {
+func (e concurentOpError) As(err any) bool {
+	if err == nil {
+		return false
+	}
+
+	er, ok := err.(concurentOpError)
+	if !ok {
+		return false
+	}
+
+	er.op = e.op
+	return true
+}
+
+func (e concurentOpError) MarshalJSON() ([]byte, error) {
 	s := make(map[string]interface{})
 	s["error"] = "another operation in progress"
 	s["operation"] = e.op
@@ -624,7 +772,7 @@ func checkConcurrentOp(cn *pbm.PBM) error {
 	// and leave it for agents to deal with.
 	for _, l := range locks {
 		if l.Heartbeat.T+pbm.StaleFrameSec >= ts.T {
-			return concurentOpErr{&l.LockHeader}
+			return concurentOpError{&l.LockHeader}
 		}
 	}
 
