@@ -27,7 +27,7 @@ type Ctl struct {
 var backupNameRE = regexp.MustCompile(`Starting backup '([0-9\-\:TZ]+)'`)
 
 func NewCtl(ctx context.Context, host, pbmContainer string) (*Ctl, error) {
-	cn, err := docker.NewClient(host, "1.39", nil, nil)
+	cn, err := docker.NewClientWithOpts(docker.WithHost(host))
 	if err != nil {
 		return nil, errors.Wrap(err, "docker client")
 	}
