@@ -115,7 +115,11 @@ func (s *StorageConf) Path() string {
 			path += "/" + s.S3.Prefix
 		}
 	case storage.Azure:
-		path = fmt.Sprintf(azure.BlobURL, s.Azure.Account) + "/" + s.Azure.Container
+		epURL := s.Azure.EndpointURL
+		if epURL == "" {
+			epURL = fmt.Sprintf(azure.BlobURL, s.Azure.Account)
+		}
+		path = epURL + "/" + s.Azure.Container
 		if s.Azure.Prefix != "" {
 			path += "/" + s.Azure.Prefix
 		}
@@ -360,7 +364,7 @@ func (p *PBM) GetConfigVar(key string) (interface{}, error) {
 		return nil, errors.New("invalid config key")
 	}
 
-	bts, err := p.Conn.Database(DB).Collection(ConfigCollection).FindOne(p.ctx, bson.D{}).DecodeBytes()
+	bts, err := p.Conn.Database(DB).Collection(ConfigCollection).FindOne(p.ctx, bson.D{}).Raw()
 	if err != nil {
 		return nil, errors.Wrap(err, "get from db")
 	}
